@@ -162,11 +162,11 @@ impl ServerSession {
             if let Ok(rv) = result {
                 match rv {
                     UnpackResult::Chunks(chunks) => {
-                        for chunk_info in chunks.iter() {
-                            let mut msg = MessageParser::new(chunk_info.clone()).parse()?;
-
-                            let msg_stream_id = chunk_info.message_header.msg_streamd_id;
+                        for chunk_info in chunks {
                             let timestamp = chunk_info.message_header.timestamp;
+                            let msg_stream_id = chunk_info.message_header.msg_streamd_id;
+
+                            let mut msg = MessageParser::new(chunk_info).parse()?;
                             self.process_messages(&mut msg, &msg_stream_id, &timestamp)
                                 .await?;
                         }
